Tournament Portsmouth, England October 23rd 1999 Barney Baker Here is Barney's winning deck - 3VP to Rob's 1 and Pierre's 1. Crypt (12 cards, min=12, max=37, avg=6.08) ------------------------------------------ 2x Jimmy Dunn 4 CEL POT for Pander:2 1x Gwendolyn 11 CEL FOR POT PRE aus tha inner circle Brujah:2 1x Crusher 9 CEL POT PRE for primogen Brujah:1 1x Salinger 9 CEL POT PRE tha archbishop Brujah antitribu:2 1x Jacko 8 CEL POT PRE obt Brujah antitribu:2 1x Richter, The Templar of Du Mont 7 CEL POT for pre Brujah antitribu:2 1x Anvil 6 CEL POT dom pre tha primogen Brujah:1 1x Bianca 6 CEL pot pre Brujah:1 1x Volker, The Puppet Prince 5 CEL pot prince Brujah:2 1x Jacob Bragg 3 cel pot Brujah antitribu:2 1x Antoinette DuChamp 1 cel pre Caitiff:2 Library (86 cards) Master (16) 2x Blood Doll 1x Celerity 1x Direct Intervention 1x Dreams of the Sphinx 1x Fame 2x Fortitude 1x Giant's Blood 1x Golconda: Inner Peace 2x Haven Uncovered 1x KRCG News Radio 2x Minion Tap 1x Sudden Reversal Action (11) 2x Ambush 3x Bum's Rush 5x Legal Manipulations 1x Media Influence Equipment (3) 1x Palatial Estate 2x Sport Bike Reaction (9) 1x Elder Intervention 4x Forced Awakening 2x Pack Tactics 2x Wake with Evening's Freshness Combat (47) 1x Acrobatics 5x Blur 1x Decapitate 2x Fists of Death 2x Flash 8x Immortal Grapple 1x Psyche! 1x Pursuit 4x Pushing the Limit 1x Rapid Thought 2x Side Strike 2x Sideslip 1x Skin of Rock 5x Skin of Steel 1x Superior Mettle 4x Taste of Vitae 3x Torn Signpost 3x Undead Strength